@@ -11,6 +11,7 @@ import math
 import cmath
 import time
 import astropy
+import cupy
 
 from numba import cuda
 import numba
@@ -297,7 +298,7 @@ def speed_vector_parallel(t1,t2,f_sampling):
     para_pool=Parallel(n_jobs=number_of_cpu)
     result_matrix=para_pool(delayed_funcs)
 
-    return np.transpose(np.array(result_matrix))
+    return np.array(result_matrix)
 
 
 
